# Ashes python API package

This package allows to modify the model (e.g. applying loads) within a time simulation in the software Ashes from www.simis.io (Aero-Servo-Hydro-Elastic-Simulation) using custom Python code. Test